"""Partner schema module."""

from datetime import datetime
from uuid import uuid4

from pydantic import BaseModel, ConfigDict, EmailStr, Field

from gso.db.models import PartnerType


class PartnerCreate(BaseModel):
    """Partner create schema."""

    partner_id: str = Field(default_factory=lambda: str(uuid4()))
    name: str
    email: EmailStr | None = None
    as_number: str | None = None
    as_set: str | None = None
    route_set: str | None = None
    black_listed_as_sets: list[str] | None = None
    additional_routers: list[str] | None = None
    additional_bgp_speakers: list[str] | None = None
    partner_type: PartnerType
    created_at: datetime = Field(default_factory=lambda: datetime.now().astimezone())
    updated_at: datetime = Field(default_factory=lambda: datetime.now().astimezone())
    model_config = ConfigDict(from_attributes=True)
